document.addEventListener('DOMContentLoaded', () => {
    const starInput = document.getElementById('starInput');
    const sortAZBtn = document.getElementById('sortAZ');
    const sortZABtn = document.getElementById('sortZA');
    const clearBtn = document.getElementById('clear');
    const result = document.getElementById('result');

    function sortStars(direction = 'asc') {
        const stars = starInput.value
            .split('\n')
            .filter(star => star.trim() !== '')
            .map(star => star.trim());

        if (stars.length === 0) {
            result.innerHTML = '<p class="placeholder">Please enter some star names first</p>';
            return;
        }

        const sortedStars = stars.sort((a, b) => {
            return direction === 'asc' 
                ? a.localeCompare(b)
                : b.localeCompare(a);
        });

        result.innerHTML = sortedStars
            .map(star => `<p>${star}</p>`)
            .join('');
    }

    function clearAll() {
        starInput.value = '';
        result.innerHTML = '<p class="placeholder">Your sorted star names will appear here</p>';
    }

    sortAZBtn.addEventListener('click', () => sortStars('asc'));
    sortZABtn.addEventListener('click', () => sortStars('desc'));
    clearBtn.addEventListener('click', clearAll);

    // Add animation when new results are displayed
    const observer = new MutationObserver((mutations) => {
        mutations.forEach((mutation) => {
            if (mutation.type === 'childList') {
                const newNodes = Array.from(mutation.addedNodes);
                newNodes.forEach((node, index) => {
                    if (node.nodeType === 1) {
                        node.style.animation = `fadeIn 0.3s ease-out ${index * 0.1}s forwards`;
                    }
                });
            }
        });
    });

    observer.observe(result, { childList: true });
});
